@@ -133,7 +133,9 @@ class SnowflakeConnector:
         schema.table in the database connected to.
         """
 
-        table_name = table.name if table.name.startswith('"') and table.name.endswith('"') else f"'{table.name.upper()}'"
+        table_name = (
+            table.name if table.name.startswith('"') and table.name.endswith('"') else f"'{table.name.upper()}'"
+        )
 
         query = f"""
             SELECT column_name, data_type, is_nullable, column_default
